==> openjdk11-src-11.0.5.u10-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/TimeZoneNames_rm.java <==
/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_rm extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "UTC",
                new String[] {
                    "",
                    "",
                    "",
                    "",
                    "",
                    "",
                }
            },
            { "timezone.excity.America/Kentucky/Monticello", "Monticello" },
            { "timezone.excity.Asia/Aqtobe", "Aqt\u00f6be" },
            { "timezone.excity.America/Belize", "Belmopan" },
            { "timezone.excity.Atlantic/St_Helena", "Sontg\u2019elena" },
            { "timezone.excity.Pacific/Ponape", "Palikir" },
            { "timezone.excity.Asia/Macau", "Macao" },
            { "timezone.excity.America/Anchorage", "Alasca" },
            { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
            { "timezone.excity.Asia/Hong_Kong", "Hongkong" },
            { "timezone.excity.Antarctica/McMurdo", "Mac Murdo" },
            { "timezone.excity.America/Indiana/Winamac", "Winamac" },
            { "timezone.excity.America/Mexico_City", "Citad da Mexico" },
            { "timezone.excity.Europe/Isle_of_Man", "Douglas" },
            { "timezone.excity.Asia/Novosibirsk", "Nowosibirsk" },
            { "timezone.excity.Asia/Baghdad", "Bagdad" },
            { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
            { "timezone.excity.Pacific/Nauru", "Yaren" },
            { "Pacific/Bougainville",
                new String[] {
                    "",
                    "",
                    "",
                    "",
                    "",
                    "",
                }
            },
            { "timezone.excity.Pacific/Fiji", "Fidschi" },
            { "timezone.excity.Asia/Kamchatka", "Kamtschatka" },
            { "timezone.excity.Europe/Lisbon", "Lissabon" },
            { "timezone.excity.Europe/Jersey", "Saint Helier" },
            { "timezone.excity.Asia/Samarkand", "Samarcanda" },
            { "timezone.excity.Pacific/Gambier", "Rikitea" },
            { "timezone.excity.America/Indiana/Marengo", "Marengo" },
            { "timezone.excity.Asia/Yakutsk", "Jakutsk" },
            { "timezone.excity.Africa/Djibouti", "Dschibuti" },
            { "timezone.excity.Atlantic/South_Georgia", "Georgia dal Sid" },
            { "timezone.excity.Pacific/Wallis", "Mat\u0101\u02bbutu" },
            { "timezone.excity.America/St_Vincent", "Saint Vincent" },
            { "timezone.excity.Asia/Singapore", "Singapur" },
            { "timezone.excity.Europe/Zaporozhye", "Saporischja" },
            { "timezone.excity.America/Cayman", "Inslas Cayman" },
            { "timezone.excity.Asia/Tashkent", "Taschkent" },
            { "timezone.excity.America/Argentina/San_Juan", "San Juan, Argentinia" },
            { "timezone.excity.America/Indiana/Vevay", "Vevay" },
            { "timezone.excity.Indian/Kerguelen", "Port-aux-Fran\u00e7ais" },
            { "Europe/Astrakhan",
                new String[] {
                    "",
                    "",
                    "",
                    "",
                    "",
                    "",
                }
            },
            { "timezone.excity.Europe/Rome", "Roma" },
            { "timezone.excity.Asia/Tokyo", "Tokio" },
            { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
            { "timezone.excity.Asia/Karachi", "Karatschi" },
            { "timezone.excity.America/Mazatlan", "Mazatl\u00e1n" },
            { "timezone.excity.Asia/Brunei", "Bandar Seri Begawan" },
            { "timezone.excity.America/Tortola", "Road Town" },
            { "timezone.excity.Asia/Dushanbe", "Duschanbe" },
            { "timezone.excity.Atlantic/Faeroe", "Inslas Feroe" },
            { "timezone.excity.Asia/Muscat", "Mascate" },
            { "Antarctica/Palmer",
                new String[] {
                    "",
                    "",
                    "",
                    "",
                    "",
                    "",
                }
            },
            { "timezone.excity.America/Port_of_Spain", "Port-of-Spain" },
            { "timezone.excity.Africa/El_Aaiun", "El Ayun" },
            { "timezone.excity.Europe/Bucharest", "Bucarest" },
            { "timezone.excity.America/Merida", "M\u00e9rida" },
            { "timezone.excity.America/North_Dakota/New_Salem", "North Dakota (New Salem)" },
            { "timezone.excity.Europe/Athens", "Athen" },
            { "timezone.excity.Pacific/Palau", "Melekok" },
            { "timezone.excity.Pacific/Truk", "Weno" },
            { "timezone.excity.Atlantic/Cape_Verde", "Cap Verd" },
            { "timezone.excity.America/Indiana/Knox", "Knox" },
            { "timezone.excity.America/Eirunepe", "Eirunep\u00e9" },
            { "timezone.excity.Asia/Bishkek", "Bischkek" },
            { "timezone.excity.America/El_Salvador", "Salvador" },
            { "America/Punta_Arenas",
                new String[] {
                    "",
                    "",
                    "",
                    "",
                    "",
                    "",
                }
            },
            { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
            { "timezone.excity.Pacific/Easter", "Insla da Pasca" },
            { "timezone.excity.Pacific/Norfolk", "Kingston" },
            { "timezone.excity.Pacific/Guam", "Hag\u00e5t\u00f1a" },
            { "timezone.excity.Europe/Zurich", "Turitg" },
            { "timezone.excity.Atlantic/Azores", "Azoras" },
            { "timezone.excity.Asia/Ashgabat", "A\u015fgabat" },
            { "timezone.excity.Asia/Urumqi", "\u00dcr\u00fcmqi" },
            { "timezone.excity.America/Anguilla", "The Valley" },
            { "timezone.excity.Pacific/Tongatapu", "Nuku\u02bbalofa" },
            { "timezone.excity.Pacific/Niue", "Alofi" },
            { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
            { "timezone.excity.Antarctica/Syowa", "Showa" },
            { "timezone.excity.America/Costa_Rica", "San Jos\u00e9" },
            { "timezone.excity.America/Noronha", "Fernando de Noronha" },
            { "timezone.excity.America/Jamaica", "Giamaica" },
            { "timezone.excity.Asia/Sakhalin", "Sachalin" },
            { "timezone.excity.America/Montserrat", "Brades" },
            { "timezone.excity.Indian/Reunion", "R\u00e9union" },
            { "timezone.excity.Europe/Guernsey", "Saint Peter Port" },
            { "timezone.excity.Europe/Copenhagen", "Copenhaghen" },
            { "timezone.excity.Pacific/Noumea", "Noum\u00e9a" },
            { "timezone.excity.Europe/London", "Londra" },
            { "timezone.excity.America/Araguaina", "Aragua\u00edna" },
            { "timezone.excity.Atlantic/Canary", "Inslas Canarias" },
            { "timezone.excity.Africa/Mogadishu", "Mogadischu" },
            { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
            { "timezone.excity.Etc/Unknown", "zona betg enconuschenta" },
            { "Asia/Famagusta",
                new String[] {
                    "",
                    "",
                    "",
                    "",
                    "",
                    "",
                }
            },
            { "timezone.excity.America/Grand_Turk", "Cockburn Town" },
            { "timezone.excity.Asia/Riyadh", "Riyad" },
            { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
            { "timezone.excity.Indian/Christmas", "Flying Fish Cove" },
            { "timezone.excity.Pacific/Guadalcanal", "Honiara" },
            { "timezone.excity.Atlantic/Stanley", "Port Stanley" },
            { "timezone.excity.America/Indiana/Petersburg", "Petersburg" },
            { "timezone.excity.Asia/Yerevan", "Jerevan" },
            { "timezone.excity.Africa/Lome", "Lom\u00e9" },
            { "timezone.excity.Europe/Uzhgorod", "Uschgorod" },
            { "Europe/Ulyanovsk",
                new String[] {
                    "",
                    "",
                    "",
                    "",
                    "",
                    "",
                }
            },
            { "timezone.excity.Asia/Choibalsan", "Tschoibalsan" },
            { "timezone.excity.Pacific/Kosrae", "Tofol" },
            { "timezone.excity.Europe/Warsaw", "Varsovia" },
            { "timezone.excity.Europe/Moscow", "Moscau" },
            { "timezone.excity.America/Aruba", "Oranjestad" },
            { "timezone.excity.America/St_Lucia", "Santa Lucia" },
            { "timezone.excity.Africa/Algiers", "Algier" },
            { "timezone.excity.America/Indiana/Tell_City", "Tell City" },
            { "timezone.excity.Africa/Khartoum", "Khartum" },
            { "timezone.excity.America/Godthab", "Godth\u00e5b" },
            { "timezone.excity.America/Cancun", "Canc\u00fan" },
            { "timezone.excity.Asia/Tehran", "Teheran" },
            { "timezone.excity.America/St_Johns", "Saint John\u2019s" },
            { "timezone.excity.America/St_Kitts", "Saint Kitts" },
            { "Asia/Srednekolymsk",
                new String[] {
                    "",
                    "",
                    "",
                    "",
                    "",
                    "",
                }
            },
            { "timezone.excity.Africa/Dar_es_Salaam", "Daressalam" },
            { "timezone.excity.Indian/Chagos", "Diego Garcia" },
            { "timezone.excity.Pacific/Galapagos", "Gal\u00e1pagos" },
            { "timezone.excity.America/Belem", "Bel\u00e9m" },
            { "timezone.excity.Europe/Tirane", "Tirana" },
            { "timezone.excity.Pacific/Tarawa", "South Tarawa" },
            { "timezone.excity.America/Argentina/Tucuman", "Tucum\u00e1n" },
            { "Europe/Saratov",
                new String[] {
                    "",
                    "",
                    "",
                    "",
                    "",
                    "",
                }
            },
            { "timezone.excity.Atlantic/Bermuda", "Bermudas" },
            { "timezone.excity.Indian/Cocos", "West Island" },
            { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
            { "timezone.excity.Asia/Makassar", "Macassar" },
            { "timezone.excity.Asia/Yekaterinburg", "Jekaterinburg" },
            { "timezone.excity.America/Indiana/Vincennes", "Vincennes" },
            { "timezone.excity.Asia/Seoul", "Seul" },
            { "timezone.excity.Africa/Sao_Tome", "S\u00e3o Tom\u00e9" },
            { "timezone.excity.Europe/Brussels", "Bruxelles" },
            { "timezone.excity.Indian/Comoro", "Comoras" },
            { "timezone.excity.America/St_Thomas", "Saint Thomas" },
            { "timezone.excity.America/Guadeloupe", "Basse-Terre" },
            { "timezone.excity.America/Miquelon", "Saint Pierre" },
            { "timezone.excity.America/Jujuy", "San Salvador de Jujuy" },
            { "timezone.excity.Europe/Vatican", "Citad dal Vatican" },
            { "timezone.excity.America/Argentina/Ushuaia", "Ushua\u00efa" },
            { "timezone.excity.America/North_Dakota/Center", "North Dakota (Central)" },
            { "timezone.excity.Indian/Maldives", "Maldivas" },
        };
        return data;
    }
}

==> openjdk11-src-11.0.18.u10-2-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/TimeZoneNames_rm.java <==
/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_rm extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] EMPTY_ZONE = new String[] {
               "",
               "",
               "",
               "",
               "",
               "",
            };
        final Object[][] data = new Object[][] {
            { "UTC", EMPTY_ZONE },
            { "timezone.excity.America/Kentucky/Monticello", "Monticello" },
            { "timezone.excity.Asia/Aqtobe", "Aqt\u00f6be" },
            { "timezone.excity.America/Belize", "Belmopan" },
            { "timezone.excity.Atlantic/St_Helena", "Sontg\u2019elena" },
            { "timezone.excity.Pacific/Ponape", "Palikir" },
            { "timezone.excity.Asia/Macau", "Macao" },
            { "timezone.excity.America/Anchorage", "Alasca" },
            { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
            { "timezone.excity.Asia/Hong_Kong", "Hongkong" },
            { "timezone.excity.Antarctica/McMurdo", "Mac Murdo" },
            { "timezone.excity.America/Indiana/Winamac", "Winamac" },
            { "timezone.excity.America/Mexico_City", "Citad da Mexico" },
            { "timezone.excity.Europe/Isle_of_Man", "Douglas" },
            { "timezone.excity.Asia/Novosibirsk", "Nowosibirsk" },
            { "timezone.excity.Asia/Baghdad", "Bagdad" },
            { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
            { "timezone.excity.Pacific/Nauru", "Yaren" },
            { "timezone.excity.Pacific/Fiji", "Fidschi" },
            { "timezone.excity.Asia/Kamchatka", "Kamtschatka" },
            { "timezone.excity.Europe/Lisbon", "Lissabon" },
            { "timezone.excity.Europe/Jersey", "Saint Helier" },
            { "timezone.excity.Asia/Samarkand", "Samarcanda" },
            { "timezone.excity.Pacific/Gambier", "Rikitea" },
            { "timezone.excity.America/Indiana/Marengo", "Marengo" },
            { "timezone.excity.Asia/Yakutsk", "Jakutsk" },
            { "timezone.excity.Africa/Djibouti", "Dschibuti" },
            { "timezone.excity.Atlantic/South_Georgia", "Georgia dal Sid" },
            { "timezone.excity.Pacific/Wallis", "Mat\u0101\u02bbutu" },
            { "timezone.excity.America/St_Vincent", "Saint Vincent" },
            { "timezone.excity.Asia/Singapore", "Singapur" },
            { "timezone.excity.Europe/Zaporozhye", "Saporischja" },
            { "timezone.excity.America/Cayman", "Inslas Cayman" },
            { "timezone.excity.Asia/Tashkent", "Taschkent" },
            { "timezone.excity.America/Argentina/San_Juan", "San Juan, Argentinia" },
            { "timezone.excity.America/Indiana/Vevay", "Vevay" },
            { "timezone.excity.Indian/Kerguelen", "Port-aux-Fran\u00e7ais" },
            { "timezone.excity.Europe/Rome", "Roma" },
            { "timezone.excity.Asia/Tokyo", "Tokio" },
            { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
            { "timezone.excity.Asia/Karachi", "Karatschi" },
            { "timezone.excity.America/Mazatlan", "Mazatl\u00e1n" },
            { "timezone.excity.Asia/Brunei", "Bandar Seri Begawan" },
            { "timezone.excity.America/Tortola", "Road Town" },
            { "timezone.excity.Asia/Dushanbe", "Duschanbe" },
            { "timezone.excity.Atlantic/Faeroe", "Inslas Feroe" },
            { "timezone.excity.Asia/Muscat", "Mascate" },
            { "timezone.excity.America/Port_of_Spain", "Port-of-Spain" },
            { "timezone.excity.Africa/El_Aaiun", "El Ayun" },
            { "timezone.excity.Europe/Bucharest", "Bucarest" },
            { "timezone.excity.America/North_Dakota/New_Salem", "North Dakota (New Salem)" },
            { "timezone.excity.Europe/Athens", "Athen" },
            { "timezone.excity.Pacific/Palau", "Melekok" },
            { "timezone.excity.Pacific/Truk", "Weno" },
            { "timezone.excity.Atlantic/Cape_Verde", "Cap Verd" },
            { "timezone.excity.America/Indiana/Knox", "Knox" },
            { "timezone.excity.America/Eirunepe", "Eirunep\u00e9" },
            { "timezone.excity.Asia/Bishkek", "Bischkek" },
            { "timezone.excity.America/El_Salvador", "Salvador" },
            { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
            { "timezone.excity.Pacific/Easter", "Insla da Pasca" },
            { "timezone.excity.Pacific/Norfolk", "Kingston" },
            { "timezone.excity.Pacific/Guam", "Hag\u00e5t\u00f1a" },
            { "timezone.excity.Europe/Zurich", "Turitg" },
            { "timezone.excity.Atlantic/Azores", "Azoras" },
            { "timezone.excity.Asia/Ashgabat", "A\u015fgabat" },
            { "timezone.excity.Asia/Urumqi", "\u00dcr\u00fcmqi" },
            { "timezone.excity.America/Anguilla", "The Valley" },
            { "timezone.excity.Pacific/Tongatapu", "Nuku\u02bbalofa" },
            { "timezone.excity.Pacific/Niue", "Alofi" },
            { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
            { "timezone.excity.Antarctica/Syowa", "Showa" },
            { "timezone.excity.America/Costa_Rica", "San Jos\u00e9" },
            { "timezone.excity.America/Noronha", "Fernando de Noronha" },
            { "timezone.excity.America/Jamaica", "Giamaica" },
            { "timezone.excity.Asia/Sakhalin", "Sachalin" },
            { "timezone.excity.America/Montserrat", "Brades" },
            { "timezone.excity.Indian/Reunion", "R\u00e9union" },
            { "timezone.excity.Europe/Guernsey", "Saint Peter Port" },
            { "timezone.excity.Europe/Copenhagen", "Copenhaghen" },
            { "timezone.excity.Pacific/Noumea", "Noum\u00e9a" },
            { "timezone.excity.Europe/London", "Londra" },
            { "timezone.excity.America/Araguaina", "Aragua\u00edna" },
            { "timezone.excity.Atlantic/Canary", "Inslas Canarias" },
            { "timezone.excity.Africa/Mogadishu", "Mogadischu" },
            { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
            { "timezone.excity.Etc/Unknown", "zona betg enconuschenta" },
            { "timezone.excity.America/Grand_Turk", "Cockburn Town" },
            { "timezone.excity.Asia/Riyadh", "Riyad" },
            { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
            { "timezone.excity.Indian/Christmas", "Flying Fish Cove" },
            { "timezone.excity.Pacific/Guadalcanal", "Honiara" },
            { "timezone.excity.Atlantic/Stanley", "Port Stanley" },
            { "timezone.excity.America/Indiana/Petersburg", "Petersburg" },
            { "timezone.excity.Asia/Yerevan", "Jerevan" },
            { "timezone.excity.Africa/Lome", "Lom\u00e9" },
            { "timezone.excity.Europe/Uzhgorod", "Uschgorod" },
            { "timezone.excity.Asia/Choibalsan", "Tschoibalsan" },
            { "timezone.excity.Pacific/Kosrae", "Tofol" },
            { "timezone.excity.Europe/Warsaw", "Varsovia" },
            { "timezone.excity.Europe/Moscow", "Moscau" },
            { "timezone.excity.America/Aruba", "Oranjestad" },
            { "timezone.excity.America/St_Lucia", "Santa Lucia" },
            { "timezone.excity.Africa/Algiers", "Algier" },
            { "timezone.excity.America/Indiana/Tell_City", "Tell City" },
            { "timezone.excity.Africa/Khartoum", "Khartum" },
            { "timezone.excity.America/Godthab", "Godth\u00e5b" },
            { "timezone.excity.Asia/Tehran", "Teheran" },
            { "timezone.excity.America/St_Johns", "Saint John\u2019s" },
            { "timezone.excity.America/St_Kitts", "Saint Kitts" },
            { "timezone.excity.Africa/Dar_es_Salaam", "Daressalam" },
            { "timezone.excity.Indian/Chagos", "Diego Garcia" },
            { "timezone.excity.Pacific/Galapagos", "Gal\u00e1pagos" },
            { "timezone.excity.America/Belem", "Bel\u00e9m" },
            { "timezone.excity.Europe/Tirane", "Tirana" },
            { "timezone.excity.Pacific/Tarawa", "South Tarawa" },
            { "timezone.excity.America/Argentina/Tucuman", "Tucum\u00e1n" },
            { "timezone.excity.Atlantic/Bermuda", "Bermudas" },
            { "timezone.excity.Indian/Cocos", "West Island" },
            { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
            { "timezone.excity.Asia/Makassar", "Macassar" },
            { "timezone.excity.Asia/Yekaterinburg", "Jekaterinburg" },
            { "timezone.excity.America/Indiana/Vincennes", "Vincennes" },
            { "timezone.excity.Asia/Seoul", "Seul" },
            { "timezone.excity.Africa/Sao_Tome", "S\u00e3o Tom\u00e9" },
            { "timezone.excity.Europe/Brussels", "Bruxelles" },
            { "timezone.excity.Indian/Comoro", "Comoras" },
            { "timezone.excity.America/St_Thomas", "Saint Thomas" },
            { "timezone.excity.America/Guadeloupe", "Basse-Terre" },
            { "timezone.excity.America/Miquelon", "Saint Pierre" },
            { "timezone.excity.America/Jujuy", "San Salvador de Jujuy" },
            { "timezone.excity.Europe/Vatican", "Citad dal Vatican" },
            { "timezone.excity.America/Argentina/Ushuaia", "Ushua\u00efa" },
            { "timezone.excity.America/North_Dakota/Center", "North Dakota (Central)" },
            { "timezone.excity.Indian/Maldives", "Maldivas" },
        };
        return data;
    }
}
